# Copyright (C) 2022 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""add parameter list to coarse fetch

Revision ID: 675905a740c1
Revises: 2dec906ab81a
Create Date: 2022-09-01 09:31:01.363768

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '675905a740c1'
down_revision = '2dec906ab81a'
branch_labels = None
depends_on = None

old_fetch_sh = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR

chmod 770 .
cd rawdata/
../productfetcher --product-locator $1
cd ../

"""

old_fetch_condor = """executable = vlass_coarse_fetch.sh
arguments = {{product_locator}}

output = vlass_coarse_fetch.out
error = vlass_coarse_fetch.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
SPOOL_DIR = {{data_location}}
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/pycapo, nraorsync://$(SBIN_PATH)/productfetcher, nraorsync://$(SPOOL_DIR)/rawdata
when_to_transfer_output = ON_EXIT
transfer_output_files = .job.ad
+nrao_output_files = "rawdata"
output_destination = nraorsync://$(SPOOL_DIR)
+WantIOProxy = True

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = HasLustre == True

queue

"""

new_fetch_sh = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR

chmod 770 .
cd rawdata/
../productfetcher --product-locator $1 --product-locator $2
cd ../

"""

new_fetch_condor = """executable = vlass_coarse_fetch.sh
arguments = {{reimaging_locator}} {{parameter_locator}}

output = vlass_coarse_fetch.out
error = vlass_coarse_fetch.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
SPOOL_DIR = {{data_location}}
should_transfer_files = yes
transfer_input_files = $ENV(HOME)/.ssh/condor_transfer, nraorsync://$(SBIN_PATH)/pycapo, nraorsync://$(SBIN_PATH)/productfetcher, nraorsync://$(SPOOL_DIR)/rawdata
when_to_transfer_output = ON_EXIT
transfer_output_files = .job.ad
+nrao_output_files = "rawdata"
output_destination = nraorsync://$(SPOOL_DIR)
+WantIOProxy = True

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

requirements = HasLustre == True

queue

"""

def upgrade():
    op.execute(
        f"""
    UPDATE workflow_templates SET content = E'{new_fetch_sh}' WHERE workflow_name = 'vlass_coarse'
    AND  filename='vlass_coarse_fetch.sh'
    """
    )

    op.execute(
        f"""
    UPDATE workflow_templates SET content = E'{new_fetch_condor}' WHERE workflow_name = 'vlass_coarse'
    AND  filename='vlass_coarse_fetch.condor'
    """
    )


def downgrade():
    op.execute(
        f"""
    UPDATE workflow_templates SET content = E'{old_fetch_sh}' WHERE workflow_name = 'vlass_coarse'
    AND  filename='vlass_coarse_fetch.sh'
    """
    )

    op.execute(
        f"""
        UPDATE workflow_templates SET content = E'{old_fetch_condor}' WHERE workflow_name = 'vlass_coarse'
        AND  filename='vlass_coarse_fetch.condor'
        """
    )

