"""create matrix tables

Revision ID: d822cf6844bb
Revises: 96477a05695d
Create Date: 2024-05-13 14:39:51.124911

"""
from alembic import op


# revision identifiers, used by Alembic.
revision = "d822cf6844bb"
down_revision = "96477a05695d"
branch_labels = None
depends_on = None

create_version_table = """CREATE TABLE IF NOT EXISTS casa_matrix_casa_versions (
    matrix_id serial PRIMARY KEY,
    casa_version varchar NOT NULL UNIQUE,
    is_cluster_compatible boolean DEFAULT true
);"""

create_capabilities_bridge_table = """CREATE TABLE IF NOT EXISTS casa_matrix_capabilities (
    capability_name varchar,
    matrix_id int,
    CONSTRAINT casa_matrix_capabilities_capability_name_fkey FOREIGN KEY (capability_name) REFERENCES capabilities (capability_name),
    CONSTRAINT casa_matrix_capabilities_matrix_id_fkey FOREIGN KEY (matrix_id) REFERENCES casa_matrix_casa_versions (matrix_id),
    UNIQUE (capability_name, matrix_id)
);"""

create_cap_name_index = """CREATE INDEX IF NOT EXISTS casa_matrix_capabilities_capability_name_idx ON casa_matrix_capabilities(capability_name);"""

create_id_index = (
    """CREATE INDEX IF NOT EXISTS casa_matrix_capabilities_matrix_id_idx ON casa_matrix_capabilities(matrix_id);"""
)


def upgrade():
    op.execute(create_version_table)
    op.execute(create_capabilities_bridge_table)
    op.execute(create_cap_name_index)
    op.execute(create_id_index)


def downgrade():
    op.execute("""DROP TABLE IF EXISTS casa_matrix_capabilities""")
    op.execute("""DROP TABLE IF EXISTS casa_matrix_casa_versions""")
